@@ -291,6 +291,11 @@ class ListenQueue(threading.Thread):
             {"tag": method.delivery_tag},
         )
 
+    def _set_draft_id(self, draft_id):
+        self.helper.draft_id = draft_id
+        self.helper.api.set_draft_id(draft_id)
+        self.helper.api_impersonate.set_draft_id(draft_id)
+
     def _data_handler(self, json_data) -> None:
         # Execute the callback
         try:
@@ -298,6 +303,7 @@ class ListenQueue(threading.Thread):
             entity_id = event_data.get("entity_id")
             entity_type = event_data.get("entity_type")
             validation_mode = event_data.get("validation_mode", "workbench")
+            force_validation = event_data.get("force_validation", False)
             # Set the API headers
             internal_data = json_data["internal"]
             work_id = internal_data["work_id"]
@@ -305,9 +311,9 @@ class ListenQueue(threading.Thread):
             self.helper.work_id = work_id
 
             self.helper.validation_mode = validation_mode
-            self.helper.draft_id = draft_id
-            self.helper.api.set_draft_id(draft_id)
-            self.helper.api_impersonate.set_draft_id(draft_id)
+            self.helper.force_validation = force_validation
+
+            self._set_draft_id(draft_id)
 
             self.helper.playbook = None
             self.helper.enrichment_shared_organizations = None
@@ -370,6 +376,7 @@ class ListenQueue(threading.Thread):
                         e
                         for e in stix_objects
                         if e["id"] == opencti_entity["standard_id"]
+                        or e["id"] == "x-opencti-" + opencti_entity["standard_id"]
                     ][0]
                     event_data["stix_objects"] = stix_objects
                     event_data["stix_entity"] = stix_entity
@@ -404,12 +411,14 @@ class ListenQueue(threading.Thread):
             message = self.callback(event_data)
             if work_id:
                 self.helper.api.work.to_processed(work_id, message)
+            self._set_draft_id("")
 
         except Exception as e:  # pylint: disable=broad-except
             self.helper.metric.inc("error_count")
             self.helper.connector_logger.error(
                 "Error in message processing, reporting error to API"
             )
+            self._set_draft_id("")
             if work_id:
                 try:
                     self.helper.api.work.to_processed(work_id, str(e), True)
@@ -774,9 +783,10 @@ class ListenStream(threading.Thread):
                         # state can be None if reset from the UI
                         # In this case, default parameters will be used but SSE Client needs to be restarted
                         if state is None:
-                            self.exit = True
-                        state["start_from"] = str(msg.id)
-                        self.helper.set_state(state)
+                            self.exit_event.set()
+                        else:
+                            state["start_from"] = str(msg.id)
+                            self.helper.set_state(state)
         except Exception as ex:
             self.helper.connector_logger.error(
                 "Error in ListenStream loop, exit.", {"reason": str(ex)}
@@ -894,6 +904,12 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
         self.opencti_token = get_config_variable(
             "OPENCTI_TOKEN", ["opencti", "token"], config
         )
+        self.opencti_custom_headers = get_config_variable(
+            "OPENCTI_CUSTOM_HEADERS",
+            ["opencti", "custom_headers"],
+            config,
+            default=None,
+        )
         self.opencti_ssl_verify = get_config_variable(
             "OPENCTI_SSL_VERIFY", ["opencti", "ssl_verify"], config, False, False
         )
@@ -954,29 +970,24 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             "CONNECTOR_LIVE_STREAM_ID",
             ["connector", "live_stream_id"],
             config,
-            False,
-            None,
         )
         self.connect_live_stream_listen_delete = get_config_variable(
             "CONNECTOR_LIVE_STREAM_LISTEN_DELETE",
             ["connector", "live_stream_listen_delete"],
             config,
-            False,
-            True,
+            default=True,
         )
         self.connect_live_stream_no_dependencies = get_config_variable(
             "CONNECTOR_LIVE_STREAM_NO_DEPENDENCIES",
             ["connector", "live_stream_no_dependencies"],
             config,
-            False,
-            False,
+            default=True,
         )
         self.connect_live_stream_with_inferences = get_config_variable(
             "CONNECTOR_LIVE_STREAM_WITH_INFERENCES",
             ["connector", "live_stream_with_inferences"],
             config,
-            False,
-            False,
+            default=False,
         )
         self.connect_live_stream_recover_iso_date = get_config_variable(
             "CONNECTOR_LIVE_STREAM_RECOVER_ISO_DATE",
@@ -993,24 +1004,22 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
         )
         self.connect_confidence_level = None  # Deprecated since OpenCTI version >= 6.0
         self.connect_scope = get_config_variable(
-            "CONNECTOR_SCOPE", ["connector", "scope"], config
+            "CONNECTOR_SCOPE", ["connector", "scope"], config, default="not-applicable"
         )
         self.connect_auto = get_config_variable(
-            "CONNECTOR_AUTO", ["connector", "auto"], config, False, False
+            "CONNECTOR_AUTO", ["connector", "auto"], config, default=False
         )
         self.bundle_send_to_queue = get_config_variable(
             "CONNECTOR_SEND_TO_QUEUE",
             ["connector", "send_to_queue"],
             config,
-            False,
-            True,
+            default=True,
         )
         self.bundle_send_to_directory = get_config_variable(
             "CONNECTOR_SEND_TO_DIRECTORY",
             ["connector", "send_to_directory"],
             config,
-            False,
-            False,
+            default=False,
         )
         self.bundle_send_to_directory_path = get_config_variable(
             "CONNECTOR_SEND_TO_DIRECTORY_PATH",
@@ -1021,32 +1030,29 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             "CONNECTOR_SEND_TO_DIRECTORY_RETENTION",
             ["connector", "send_to_directory_retention"],
             config,
-            True,
-            7,
+            isNumber=True,
+            default=7,
         )
         self.connect_only_contextual = get_config_variable(
             "CONNECTOR_ONLY_CONTEXTUAL",
             ["connector", "only_contextual"],
             config,
-            False,
-            False,
+            default=False,
         )
         self.log_level = get_config_variable(
-            "CONNECTOR_LOG_LEVEL", ["connector", "log_level"], config, default="INFO"
+            "CONNECTOR_LOG_LEVEL", ["connector", "log_level"], config, default="ERROR"
         ).upper()
         self.connect_run_and_terminate = get_config_variable(
             "CONNECTOR_RUN_AND_TERMINATE",
             ["connector", "run_and_terminate"],
             config,
-            False,
-            False,
+            default=False,
         )
         self.connect_validate_before_import = get_config_variable(
             "CONNECTOR_VALIDATE_BEFORE_IMPORT",
             ["connector", "validate_before_import"],
             config,
-            False,
-            False,
+            default=False,
         )
         self.scheduler = sched.scheduler(time.time, time.sleep)
         # Start up the server to expose the metrics.
@@ -1054,11 +1060,14 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             "CONNECTOR_EXPOSE_METRICS",
             ["connector", "expose_metrics"],
             config,
-            False,
-            False,
+            default=False,
         )
         metrics_port = get_config_variable(
-            "CONNECTOR_METRICS_PORT", ["connector", "metrics_port"], config, True, 9095
+            "CONNECTOR_METRICS_PORT",
+            ["connector", "metrics_port"],
+            config,
+            isNumber=True,
+            default=9095,
         )
         # Initialize ConnectorInfo instance
         self.connector_info = ConnectorInfo()
@@ -1070,6 +1079,7 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             self.log_level,
             self.opencti_ssl_verify,
             json_logging=self.opencti_json_logging,
+            custom_headers=self.opencti_custom_headers,
             bundle_send_to_queue=self.bundle_send_to_queue,
         )
         # - Impersonate API that will use applicant id
@@ -1080,6 +1090,7 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             self.log_level,
             self.opencti_ssl_verify,
             json_logging=self.opencti_json_logging,
+            custom_headers=self.opencti_custom_headers,
             bundle_send_to_queue=self.bundle_send_to_queue,
         )
         self.connector_logger = self.api.logger_class(self.connect_name)
@@ -1102,7 +1113,11 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             self.connect_auto,
             self.connect_only_contextual,
             playbook_compatible,
-            self.listen_protocol_api_uri + self.listen_protocol_api_path,
+            (
+                self.listen_protocol_api_uri + self.listen_protocol_api_path
+                if self.listen_protocol == "API"
+                else None
+            ),
         )
         connector_configuration = self.api.connector.register(self.connector)
         self.connector_logger.info(
@@ -1110,6 +1125,7 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
         )
         self.work_id = None
         self.validation_mode = "workbench"
+        self.force_validation = False
         self.draft_id = None
         self.playbook = None
         self.enrichment_shared_organizations = None
@@ -1760,6 +1776,7 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
         update = kwargs.get("update", False)
         event_version = kwargs.get("event_version", None)
         bypass_validation = kwargs.get("bypass_validation", False)
+        force_validation = kwargs.get("force_validation", self.force_validation)
         entity_id = kwargs.get("entity_id", None)
         file_markings = kwargs.get("file_markings", None)
         file_name = kwargs.get("file_name", None)
@@ -1822,7 +1839,11 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
         if not file_name and work_id:
             file_name = f"{work_id}.json"
 
-        if self.connect_validate_before_import and not bypass_validation and file_name:
+        if (
+            (self.connect_validate_before_import or force_validation)
+            and not bypass_validation
+            and file_name
+        ):
             if validation_mode == "workbench":
                 self.api.upload_pending_file(
                     file_name=file_name,
@@ -1839,6 +1860,8 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
                 if not draft_id:
                     self.connector_logger.error("Draft couldn't be created")
                     return []
+                if work_id:
+                    self.api.work.add_draft_context(work_id, draft_id)
 
         # If directory setup, write the bundle to the target directory
         if bundle_send_to_directory and bundle_send_to_directory_path is not None:
@@ -1897,14 +1920,13 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             os.rename(write_file, final_write_file)
 
         stix2_splitter = OpenCTIStix2Splitter()
-        (
-            expectations_number,
-            bundles,
-        ) = stix2_splitter.split_bundle_with_expectations(
-            bundle=bundle,
-            use_json=True,
-            event_version=event_version,
-            cleanup_inconsistent_bundle=cleanup_inconsistent_bundle,
+        (expectations_number, _, bundles) = (
+            stix2_splitter.split_bundle_with_expectations(
+                bundle=bundle,
+                use_json=True,
+                event_version=event_version,
+                cleanup_inconsistent_bundle=cleanup_inconsistent_bundle,
+            )
         )
 
         if len(bundles) == 0:
@@ -1912,8 +1934,6 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
             raise ValueError("Nothing to import")
 
         if bundle_send_to_queue:
-            if work_id and draft_id:
-                self.api.work.add_draft_context(work_id, draft_id)
             if entities_types is None:
                 entities_types = []
             if self.queue_protocol == "amqp":
@@ -1963,6 +1983,7 @@ class OpenCTIConnectorHelper:  # pylint: disable=too-many-public-methods
                 self.api.send_bundle_to_api(
                     connector_id=self.connector_id, bundle=bundle, work_id=work_id
                 )
+                self.metric.inc("bundle_send")
             else:
                 raise ValueError(
                     f"{self.queue_protocol}: this queue protocol is not supported"
