@@ -17,6 +17,14 @@ class CaseRfi:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -206,7 +214,7 @@ class CaseRfi:
                         }
                         ... on StixCyberObservable {
                             observable_value
-                        }                        
+                        }
                         ... on StixCoreRelationship {
                             standard_id
                             spec_version
@@ -232,6 +240,14 @@ class CaseRfi:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -318,6 +334,8 @@ class CaseRfi:
             modified
             name
             description
+            severity
+            priority
             information_types
             objects(all: true) {
                 edges {
@@ -415,7 +433,7 @@ class CaseRfi:
                         }
                         ... on StixCyberObservable {
                             observable_value
-                        }                        
+                        }
                         ... on StixCoreRelationship {
                             standard_id
                             spec_version
@@ -457,9 +475,13 @@ class CaseRfi:
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "case-rfi--" + id
 
+    @staticmethod
+    def generate_id_from_data(data):
+        return CaseRfi.generate_id(data["name"], data["created"])
+
     """
         List Case Rfi objects
-        
+
         :param filters: the filters to apply
         :param search: the search keyword
         :param first: return the first n rows from the after ID (or the beginning if not set)
@@ -478,8 +500,6 @@ class CaseRfi:
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         with_files = kwargs.get("withFiles", False)
-        if get_all:
-            first = 500
 
         self.opencti.app_logger.info(
             "Listing Case Rfis with filters", {"filters": json.dumps(filters)}
@@ -526,7 +546,7 @@ class CaseRfi:
             data = self.opencti.process_multiple(result["data"]["caseRfis"])
             final_data = final_data + data
             while result["data"]["caseRfis"]["pageInfo"]["hasNextPage"]:
-                after = result["date"]["caseRfis"]["pageInfo"]["endCursor"]
+                after = result["data"]["caseRfis"]["pageInfo"]["endCursor"]
                 self.opencti.app_logger.info("Listing Case Rfis", {"after": after})
                 result = self.opencti.query(
                     query,
@@ -670,13 +690,18 @@ class CaseRfi:
         objects = kwargs.get("objects", None)
         object_marking = kwargs.get("objectMarking", None)
         object_label = kwargs.get("objectLabel", None)
+        object_assignee = kwargs.get("objectAssignee", None)
+        object_participant = kwargs.get("objectParticipant", None)
         external_references = kwargs.get("externalReferences", None)
         revoked = kwargs.get("revoked", None)
+        severity = kwargs.get("severity", None)
+        priority = kwargs.get("priority", None)
         confidence = kwargs.get("confidence", None)
         lang = kwargs.get("lang", None)
         created = kwargs.get("created", None)
         modified = kwargs.get("modified", None)
         name = kwargs.get("name", None)
+        content = kwargs.get("content", None)
         description = kwargs.get("description", None)
         x_opencti_stix_ids = kwargs.get("x_opencti_stix_ids", None)
         granted_refs = kwargs.get("objectOrganization", None)
@@ -705,15 +730,20 @@ class CaseRfi:
                         "objectMarking": object_marking,
                         "objectLabel": object_label,
                         "objectOrganization": granted_refs,
+                        "objectAssignee": object_assignee,
+                        "objectParticipant": object_participant,
                         "objects": objects,
                         "externalReferences": external_references,
                         "revoked": revoked,
+                        "severity": severity,
+                        "priority": priority,
                         "confidence": confidence,
                         "lang": lang,
                         "created": created,
                         "modified": modified,
                         "name": name,
                         "description": description,
+                        "content": content,
                         "x_opencti_stix_ids": x_opencti_stix_ids,
                         "x_opencti_workflow_id": x_opencti_workflow_id,
                         "update": update,
@@ -747,7 +777,7 @@ class CaseRfi:
                 },
             )
             query = """
-               mutation CaseRfiEditRelationAdd($id: ID!, $input: StixRefRelationshipAddInput) {
+               mutation CaseRfiEditRelationAdd($id: ID!, $input: StixRefRelationshipAddInput!) {
                    stixDomainObjectEdit(id: $id) {
                         relationAdd(input: $input) {
                             id
@@ -842,6 +872,23 @@ class CaseRfi:
                 stix_object["x_opencti_workflow_id"] = (
                     self.opencti.get_attribute_in_extension("workflow_id", stix_object)
                 )
+            if "x_opencti_assignee_ids" not in stix_object:
+                stix_object["x_opencti_assignee_ids"] = (
+                    self.opencti.get_attribute_in_extension("assignee_ids", stix_object)
+                )
+            if "x_opencti_content" not in stix_object or "content" not in stix_object:
+                stix_object["content"] = self.opencti.get_attribute_in_extension(
+                    "content", stix_object
+                )
+            if "x_opencti_content" in stix_object:
+                stix_object["content"] = stix_object["x_opencti_content"]
+
+            if "x_opencti_participant_ids" not in stix_object:
+                stix_object["x_opencti_participant_ids"] = (
+                    self.opencti.get_attribute_in_extension(
+                        "participant_ids", stix_object
+                    )
+                )
 
             return self.create(
                 stix_id=stix_object["id"],
@@ -862,7 +909,14 @@ class CaseRfi:
                     if "external_references_ids" in extras
                     else None
                 ),
+                content=(
+                    self.opencti.stix2.convert_markdown(stix_object["content"])
+                    if "content" in stix_object
+                    else None
+                ),
                 revoked=stix_object["revoked"] if "revoked" in stix_object else None,
+                severity=stix_object["severity"] if "severity" in stix_object else None,
+                priority=stix_object["priority"] if "priority" in stix_object else None,
                 confidence=(
                     stix_object["confidence"] if "confidence" in stix_object else None
                 ),
@@ -885,6 +939,16 @@ class CaseRfi:
                     if "x_opencti_granted_refs" in stix_object
                     else None
                 ),
+                objectAssignee=(
+                    stix_object["x_opencti_assignee_ids"]
+                    if "x_opencti_assignee_ids" in stix_object
+                    else None
+                ),
+                objectParticipant=(
+                    stix_object["x_opencti_participant_ids"]
+                    if "x_opencti_participant_ids" in stix_object
+                    else None
+                ),
                 x_opencti_workflow_id=(
                     stix_object["x_opencti_workflow_id"]
                     if "x_opencti_workflow_id" in stix_object
