@@ -16,6 +16,14 @@ class Feedback:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -204,6 +212,14 @@ class Feedback:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -419,6 +435,10 @@ class Feedback:
         id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
         return "feedback--" + id
 
+    @staticmethod
+    def generate_id_from_data(data):
+        return Feedback.generate_id(data["name"])
+
     """
         List Feedback objects
         
@@ -440,8 +460,6 @@ class Feedback:
         get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
         with_files = kwargs.get("withFiles", False)
-        if get_all:
-            first = 500
 
         self.opencti.app_logger.info(
             "Listing Feedbacks with filters", {"filters": json.dumps(filters)}
@@ -488,7 +506,7 @@ class Feedback:
             data = self.opencti.process_multiple(result["data"]["feedbacks"])
             final_data = final_data + data
             while result["data"]["feedbacks"]["pageInfo"]["hasNextPage"]:
-                after = result["date"]["feedbacks"]["pageInfo"]["endCursor"]
+                after = result["data"]["feedbacks"]["pageInfo"]["endCursor"]
                 self.opencti.app_logger.info("Listing Feedbacks", {"after": after})
                 result = self.opencti.query(
                     query,
