@@ -1,11 +1,8 @@
 # coding: utf-8
 
 import json
-import uuid
 
-from stix2.canonicalization.Canonicalize import canonicalize
-
-from pycti.entities import LOGGER
+from pycti.utils.opencti_stix2_identifier import kill_chain_phase_generate_id
 
 
 class KillChainPhase:
@@ -27,10 +24,13 @@ class KillChainPhase:
 
     @staticmethod
     def generate_id(phase_name, kill_chain_name):
-        data = {"phase_name": phase_name, "kill_chain_name": kill_chain_name}
-        data = canonicalize(data, utf8=False)
-        id = str(uuid.uuid5(uuid.UUID("00abedb4-aa42-466c-9c01-fed23315a9b7"), data))
-        return "kill-chain-phase--" + id
+        return kill_chain_phase_generate_id(
+            phase_name=phase_name, kill_chain_name=kill_chain_name
+        )
+
+    @staticmethod
+    def generate_id_from_data(data):
+        return KillChainPhase.generate_id(data["phase_name"], data["kill_chain_name"])
 
     """
         List Kill-Chain-Phase objects
@@ -48,17 +48,14 @@ class KillChainPhase:
         order_by = kwargs.get("orderBy", None)
         order_mode = kwargs.get("orderMode", None)
         custom_attributes = kwargs.get("customAttributes", None)
-        get_all = kwargs.get("getAll", False)
         with_pagination = kwargs.get("withPagination", False)
-        if get_all:
-            first = 500
 
-        LOGGER.info(
-            "Listing Kill-Chain-Phase with filters " + json.dumps(filters) + "."
+        self.opencti.app_logger.info(
+            "Listing Kill-Chain-Phase with filters", {"filters": json.dumps(filters)}
         )
         query = (
             """
-            query KillChainPhases($filters: [KillChainPhasesFiltering], $first: Int, $after: ID, $orderBy: KillChainPhasesOrdering, $orderMode: OrderingMode) {
+            query KillChainPhases($filters: FilterGroup, $first: Int, $after: ID, $orderBy: KillChainPhasesOrdering, $orderMode: OrderingMode) {
                 killChainPhases(filters: $filters, first: $first, after: $after, orderBy: $orderBy, orderMode: $orderMode) {
                     edges {
                         node {
@@ -104,7 +101,7 @@ class KillChainPhase:
         id = kwargs.get("id", None)
         filters = kwargs.get("filters", None)
         if id is not None:
-            LOGGER.info("Reading Kill-Chain-Phase {%s}.", id)
+            self.opencti.app_logger.info("Reading Kill-Chain-Phase", {"id": id})
             query = (
                 """
                 query KillChainPhase($id: String!) {
@@ -127,7 +124,9 @@ class KillChainPhase:
             else:
                 return None
         else:
-            LOGGER.error("[opencti_kill_chain_phase] Missing parameters: id or filters")
+            self.opencti.app_logger.error(
+                "[opencti_kill_chain_phase] Missing parameters: id or filters"
+            )
             return None
 
     """
@@ -147,10 +146,12 @@ class KillChainPhase:
         update = kwargs.get("update", False)
 
         if kill_chain_name is not None and phase_name is not None:
-            LOGGER.info("Creating Kill-Chain-Phase {%s}.", phase_name)
+            self.opencti.app_logger.info(
+                "Creating Kill-Chain-Phase", {"name": phase_name}
+            )
             query = (
                 """
-                mutation KillChainPhaseAdd($input: KillChainPhaseAddInput) {
+                mutation KillChainPhaseAdd($input: KillChainPhaseAddInput!) {
                     killChainPhaseAdd(input: $input) {
                         """
                 + self.properties
@@ -177,7 +178,7 @@ class KillChainPhase:
                 result["data"]["killChainPhaseAdd"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_kill_chain_phase] Missing parameters: kill_chain_name and phase_name",
             )
 
@@ -193,7 +194,7 @@ class KillChainPhase:
         id = kwargs.get("id", None)
         input = kwargs.get("input", None)
         if id is not None and input is not None:
-            LOGGER.info("Updating Kill chain {%s}.", id)
+            self.opencti.app_logger.info("Updating Kill chain", {"id": id})
             query = """
                     mutation KillChainPhaseEdit($id: ID!, $input: [EditInput]!) {
                         killChainPhaseEdit(id: $id) {
@@ -216,7 +217,7 @@ class KillChainPhase:
                 result["data"]["killChainPhaseEdit"]["fieldPatch"]
             )
         else:
-            LOGGER.error(
+            self.opencti.app_logger.error(
                 "[opencti_kill_chain] Missing parameters: id and key and value"
             )
             return None
@@ -224,7 +225,7 @@ class KillChainPhase:
     def delete(self, **kwargs):
         id = kwargs.get("id", None)
         if id is not None:
-            LOGGER.info("Deleting Kill-Chain-Phase {%s}.", id)
+            self.opencti.app_logger.info("Deleting Kill-Chain-Phase", {"id": id})
             query = """
                  mutation KillChainPhaseEdit($id: ID!) {
                      killChainPhaseEdit(id: $id) {
@@ -234,5 +235,7 @@ class KillChainPhase:
              """
             self.opencti.query(query, {"id": id})
         else:
-            LOGGER.error("[opencti_kill_chain_phase] Missing parameters: id")
+            self.opencti.app_logger.error(
+                "[opencti_kill_chain_phase] Missing parameters: id"
+            )
             return None
