@@ -48,9 +48,6 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
         with_pagination = kwargs.get("withPagination", False)
         with_files = kwargs.get("withFiles", False)
 
-        if get_all:
-            first = 100
-
         self.opencti.app_logger.info(
             "Listing StixCyberObservables with filters",
             {"filters": json.dumps(filters)},
@@ -184,15 +181,17 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
         id = kwargs.get("id", None)
         file_name = kwargs.get("file_name", None)
         data = kwargs.get("data", None)
+        file_markings = kwargs.get("fileMarkings", None)
         version = kwargs.get("version", None)
         mime_type = kwargs.get("mime_type", "text/plain")
         no_trigger_import = kwargs.get("no_trigger_import", False)
+        embedded = kwargs.get("embedded", False)
         if id is not None and file_name is not None:
             final_file_name = os.path.basename(file_name)
             query = """
-                    mutation StixCyberObservableEdit($id: ID!, $file: Upload!, $version: DateTime, $noTriggerImport: Boolean) {
+                    mutation StixCyberObservableEdit($id: ID!, $file: Upload!, $fileMarkings: [String], $version: DateTime, $noTriggerImport: Boolean, $embedded: Boolean) {
                         stixCyberObservableEdit(id: $id) {
-                            importPush(file: $file, version: $version, noTriggerImport: $noTriggerImport) {
+                            importPush(file: $file, version: $version, fileMarkings: $fileMarkings, noTriggerImport: $noTriggerImport, embedded: $embedded) {
                                 id
                                 name
                             }
@@ -214,12 +213,14 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                 {
                     "id": id,
                     "file": (self.file(final_file_name, data, mime_type)),
+                    "fileMarkings": file_markings,
                     "version": version,
                     "noTriggerImport": (
                         no_trigger_import
                         if isinstance(no_trigger_import, bool)
                         else no_trigger_import == "True"
                     ),
+                    "embedded": embedded,
                 },
             )
         else:
@@ -275,6 +276,8 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
             type = "IPv4-Addr"
         elif type.lower() == "ipv6-addr":
             type = "IPv6-Addr"
+        elif type.lower() == "persona":
+            type = "Persona"
         elif type.lower() == "hostname" or type.lower() == "x-opencti-hostname":
             type = "Hostname"
         elif type.lower() == "payment-card" or type.lower() == "x-opencti-payment-card":
@@ -406,6 +409,7 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                     $Credential: CredentialAddInput
                     $TrackingNumber: TrackingNumberAddInput
                     $PaymentCard: PaymentCardAddInput
+                    $Persona: PersonaAddInput
                     $MediaContent: MediaContentAddInput
                 ) {
                     stixCyberObservableAdd(
@@ -450,6 +454,7 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                         Credential: $Credential
                         TrackingNumber: $TrackingNumber
                         PaymentCard: $PaymentCard
+                        Persona: $Persona
                         MediaContent: $MediaContent
                     ) {
                         id
@@ -744,6 +749,16 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                         if "dst_port" in observable_data
                         else None
                     ),
+                    "networkSrc": (
+                        observable_data["src_ref"]
+                        if "src_ref" in observable_data
+                        else None
+                    ),
+                    "networkDst": (
+                        observable_data["dst_ref"]
+                        if "dst_ref" in observable_data
+                        else None
+                    ),
                     "protocols": (
                         observable_data["protocols"]
                         if "protocols" in observable_data
@@ -796,6 +811,18 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                     ),
                 }
             elif type == "Software":
+                if (
+                    "x_opencti_product" not in observable_data
+                    and self.opencti.get_attribute_in_extension(
+                        "x_opencti_product", observable_data
+                    )
+                    is not None
+                ):
+                    observable_data["x_opencti_product"] = (
+                        self.opencti.get_attribute_in_extension(
+                            "x_opencti_product", observable_data
+                        )
+                    )
                 input_variables["Software"] = {
                     "name": (
                         observable_data["name"] if "name" in observable_data else None
@@ -819,6 +846,11 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                         if "version" in observable_data
                         else None
                     ),
+                    "x_opencti_product": (
+                        observable_data["x_opencti_product"]
+                        if "x_opencti_product" in observable_data
+                        else None
+                    ),
                 }
             elif type == "Url":
                 input_variables["Url"] = {
@@ -1012,6 +1044,19 @@ class StixCyberObservable(StixCyberObservableDeprecatedMixin):
                         else None
                     ),
                 }
+            elif type == "Persona":
+                input_variables["Persona"] = {
+                    "persona_name": (
+                        observable_data["persona_name"]
+                        if "persona_name" in observable_data
+                        else None
+                    ),
+                    "persona_type": (
+                        observable_data["persona_type"]
+                        if "persona_type" in observable_data
+                        else None
+                    ),
+                }
             elif type == "Payment-Card" or type.lower() == "x-opencti-payment-card":
                 input_variables["PaymentCard"] = {
                     "card_number": (
