@@ -1,6 +1,4 @@
-# coding: utf-8
-
-from pycti.entities import LOGGER
+import json
 
 
 class StixObjectOrStixRelationship:
@@ -33,13 +31,9 @@ class StixObjectOrStixRelationship:
                         created
                         modified
                         objectLabel {
-                            edges {
-                                node {
-                                    id
-                                    value
-                                    color
-                                }
-                            }
+                            id
+                            value
+                            color
                         }
                     }
                     ... on Organization {
@@ -51,29 +45,26 @@ class StixObjectOrStixRelationship:
                         x_opencti_lastname
                     }
                 }
+                objectOrganization {
+                    id
+                    standard_id
+                    name
+                }
                 objectMarking {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            definition_type
-                            definition
-                            created
-                            modified
-                            x_opencti_order
-                            x_opencti_color
-                        }
-                    }
+                    id
+                    standard_id
+                    entity_type
+                    definition_type
+                    definition
+                    created
+                    modified
+                    x_opencti_order
+                    x_opencti_color
                 }
                 objectLabel {
-                    edges {
-                        node {
-                            id
-                            value
-                            color
-                        }
-                    }
+                    id
+                    value
+                    color
                 }
                 externalReferences {
                     edges {
@@ -105,18 +96,14 @@ class StixObjectOrStixRelationship:
                 x_mitre_detection
                 x_mitre_id
                 killChainPhases {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            kill_chain_name
-                            phase_name
-                            x_opencti_order
-                            created
-                            modified
-                        }
-                    }
+                  id
+                  standard_id
+                  entity_type
+                  kill_chain_name
+                  phase_name
+                  x_opencti_order
+                  created
+                  modified
                 }
             }
             ... on Campaign {
@@ -261,18 +248,14 @@ class StixObjectOrStixRelationship:
                 implementation_languages
                 capabilities
                 killChainPhases {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            kill_chain_name
-                            phase_name
-                            x_opencti_order
-                            created
-                            modified
-                        }
-                    }
+                  id
+                  standard_id
+                  entity_type
+                  kill_chain_name
+                  phase_name
+                  x_opencti_order
+                  created
+                  modified
                 }
             }
             ... on ThreatActor {
@@ -297,28 +280,67 @@ class StixObjectOrStixRelationship:
                 tool_types
                 tool_version
                 killChainPhases {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            kill_chain_name
-                            phase_name
-                            x_opencti_order
-                            created
-                            modified
-                        }
-                    }
+                  id
+                  standard_id
+                  entity_type
+                  kill_chain_name
+                  phase_name
+                  x_opencti_order
+                  created
+                  modified
                 }
             }
             ... on Vulnerability {
                 name
                 description
-                x_opencti_base_score
-                x_opencti_base_severity
-                x_opencti_attack_vector
-                x_opencti_integrity_impact
-                x_opencti_availability_impact
+                x_opencti_aliases
+                x_opencti_cvss_vector_string
+                x_opencti_cvss_base_score
+                x_opencti_cvss_base_severity
+                x_opencti_cvss_attack_vector
+                x_opencti_cvss_attack_complexity
+                x_opencti_cvss_privileges_required
+                x_opencti_cvss_user_interaction
+                x_opencti_cvss_scope
+                x_opencti_cvss_confidentiality_impact
+                x_opencti_cvss_integrity_impact
+                x_opencti_cvss_availability_impact
+                x_opencti_cvss_exploit_code_maturity
+                x_opencti_cvss_remediation_level
+                x_opencti_cvss_report_confidence
+                x_opencti_cvss_temporal_score
+                x_opencti_cvss_v2_vector_string
+                x_opencti_cvss_v2_base_score
+                x_opencti_cvss_v2_access_vector
+                x_opencti_cvss_v2_access_complexity
+                x_opencti_cvss_v2_authentication
+                x_opencti_cvss_v2_confidentiality_impact
+                x_opencti_cvss_v2_integrity_impact
+                x_opencti_cvss_v2_availability_impact
+                x_opencti_cvss_v2_exploitability
+                x_opencti_cvss_v2_remediation_level
+                x_opencti_cvss_v2_report_confidence
+                x_opencti_cvss_v2_temporal_score
+                x_opencti_cvss_v4_vector_string
+                x_opencti_cvss_v4_base_score
+                x_opencti_cvss_v4_base_severity
+                x_opencti_cvss_v4_attack_vector
+                x_opencti_cvss_v4_attack_complexity
+                x_opencti_cvss_v4_attack_requirements
+                x_opencti_cvss_v4_privileges_required
+                x_opencti_cvss_v4_user_interaction
+                x_opencti_cvss_v4_confidentiality_impact_v
+                x_opencti_cvss_v4_confidentiality_impact_s
+                x_opencti_cvss_v4_integrity_impact_v
+                x_opencti_cvss_v4_integrity_impact_s
+                x_opencti_cvss_v4_availability_impact_v
+                x_opencti_cvss_v4_availability_impact_s
+                x_opencti_cvss_v4_exploit_maturity
+                x_opencti_cwe
+                x_opencti_cisa_kev
+                x_opencti_epss_score
+                x_opencti_epss_percentile
+                x_opencti_score
             }
             ... on Incident {
                 name
@@ -353,11 +375,15 @@ class StixObjectOrStixRelationship:
             }
             ... on Case {
                 name
-            }            
+            }
             ... on StixCyberObservable {
                 observable_value
             }
             ... on StixCoreRelationship {
+                id
+                standard_id
+                entity_type
+                parent_types
                 createdBy {
                     ... on Identity {
                         id
@@ -380,28 +406,20 @@ class StixObjectOrStixRelationship:
                     }
                 }
                 objectMarking {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            definition_type
-                            definition
-                            created
-                            modified
-                            x_opencti_order
-                            x_opencti_color
-                        }
-                    }
+                    id
+                    standard_id
+                    entity_type
+                    definition_type
+                    definition
+                    created
+                    modified
+                    x_opencti_order
+                    x_opencti_color
                 }
                 objectLabel {
-                    edges {
-                        node {
-                            id
-                            value
-                            color
-                        }
-                    }
+                    id
+                    value
+                    color
                 }
                 externalReferences {
                     edges {
@@ -428,6 +446,10 @@ class StixObjectOrStixRelationship:
                 stop_time
             }
             ... on StixSightingRelationship {
+                id
+                standard_id
+                entity_type
+                parent_types
                 createdBy {
                     ... on Identity {
                         id
@@ -450,28 +472,20 @@ class StixObjectOrStixRelationship:
                     }
                 }
                 objectMarking {
-                    edges {
-                        node {
-                            id
-                            standard_id
-                            entity_type
-                            definition_type
-                            definition
-                            created
-                            modified
-                            x_opencti_order
-                            x_opencti_color
-                        }
-                    }
+                    id
+                    standard_id
+                    entity_type
+                    definition_type
+                    definition
+                    created
+                    modified
+                    x_opencti_order
+                    x_opencti_color
                 }
                 objectLabel {
-                    edges {
-                        node {
-                            id
-                            value
-                            color
-                        }
-                    }
+                    id
+                    value
+                    color
                 }
                 externalReferences {
                     edges {
@@ -510,13 +524,16 @@ class StixObjectOrStixRelationship:
     def read(self, **kwargs):
         id = kwargs.get("id", None)
         custom_attributes = kwargs.get("customAttributes", None)
+        filters = kwargs.get("filters", None)
         if id is not None:
-            LOGGER.info("Reading StixObjectOrStixRelationship {%s}.", id)
+            self.opencti.app_logger.info(
+                "Reading StixObjectOrStixRelationship", {"id": id}
+            )
             query = (
                 """
-                query StixObjectOrStixRelationship($id: String!) {
-                    stixObjectOrStixRelationship(id: $id) {
-                        """
+                    query StixObjectOrStixRelationship($id: String!) {
+                        stixObjectOrStixRelationship(id: $id) {
+                            """
                 + (
                     custom_attributes
                     if custom_attributes is not None
@@ -531,6 +548,85 @@ class StixObjectOrStixRelationship:
             return self.opencti.process_multiple_fields(
                 result["data"]["stixObjectOrStixRelationship"]
             )
+        elif filters is not None:
+            result = self.list(filters=filters)
+            if len(result) > 0:
+                return result[0]
+            else:
+                return None
         else:
-            LOGGER.error("Missing parameters: id")
+            self.opencti.app_logger.error("Missing parameters: id")
             return None
+
+    def list(self, **kwargs):
+        filters = kwargs.get("filters", None)
+        search = kwargs.get("search", None)
+        first = kwargs.get("first", 100)
+        after = kwargs.get("after", None)
+        get_all = kwargs.get("getAll", False)
+        with_pagination = kwargs.get("with_pagination", False)
+        custom_attributes = kwargs.get("customAttributes", None)
+
+        self.opencti.app_logger.info(
+            "Listing StixObjectOrStixRelationships with filters",
+            {"filters": json.dumps(filters)},
+        )
+        query = (
+            """
+                        query StixObjectOrStixRelationships($filters: FilterGroup, $search: String, $first: Int, $after: ID) {
+                            stixObjectOrStixRelationships(filters: $filters, search: $search, first: $first, after: $after) {
+                                edges {
+                                    node {
+                                        """
+            + (custom_attributes if custom_attributes is not None else self.properties)
+            + """
+                                }
+                            }
+                            pageInfo {
+                                startCursor
+                                endCursor
+                                hasNextPage
+                                hasPreviousPage
+                                globalCount
+                            }
+                        }
+                    }
+                """
+        )
+        variables = {
+            "filters": filters,
+            "search": search,
+            "first": first,
+            "after": after,
+        }
+        result = self.opencti.query(
+            query,
+            variables,
+        )
+
+        if get_all:
+            final_data = []
+            data = self.opencti.process_multiple(
+                result["data"]["stixObjectOrStixRelationships"]
+            )
+            final_data = final_data + data
+            while result["data"]["stixObjectOrStixRelationships"]["pageInfo"][
+                "hasNextPage"
+            ]:
+                after = result["data"]["stixObjectOrStixRelationships"]["pageInfo"][
+                    "endCursor"
+                ]
+                self.opencti.app_logger.info(
+                    "Listing stixObjectOrStixRelationships", {"after": after}
+                )
+                after_variables = {**variables, **{"after": after}}
+                result = self.opencti.query(query, after_variables)
+                data = self.opencti.process_multiple(
+                    result["data"]["stixObjectOrStixRelationships"]
+                )
+                final_data = final_data + data
+            return final_data
+        else:
+            return self.opencti.process_multiple(
+                result["data"]["stixObjectOrStixRelationships"], with_pagination
+            )
