@@ -17,6 +17,14 @@ class Task:
             spec_version
             created_at
             updated_at
+            status {
+                id
+                template {
+                  id
+                  name
+                  color
+                }
+            }
             createdBy {
                 ... on Identity {
                     id
@@ -299,7 +307,7 @@ class Task:
             data = self.opencti.process_multiple(result["data"]["tasks"])
             final_data = final_data + data
             while result["data"]["tasks"]["pageInfo"]["hasNextPage"]:
-                after = result["date"]["tasks"]["pageInfo"]["endCursor"]
+                after = result["data"]["tasks"]["pageInfo"]["endCursor"]
                 self.opencti.app_logger.info("Listing Tasks", {"after": after})
                 result = self.opencti.query(
                     query,
